"""Tests K2fov.plot"""

# from .. import plot

"""
def test_basics():
    # Make sure this runs without exception.
    try:
        import matplotlib
        plot.create_context_plot(180, 0)
        plot.create_context_plot_zoomed(180, 0)
    except ImportError:
        pass
"""
